{% extends 'mistral/default/table.html' %}
{% load i18n %}
{% block title %}{% trans "Executions" %}{% endblock %}

{% block page_header %}
  {% include "horizon/common/_page_header.html" with title=_("Executions") %}
{% endblock page_header %}
